@@ -12,7 +12,7 @@ use HTML::Perlinfo::Common;
 use base qw(Exporter HTML::Perlinfo::Base);
 our @EXPORT = qw(perlinfo);
 
-our $VERSION = '1.69';
+our $VERSION = '1.70';
 
 sub perlinfo {
   my ($opt) = @_;
@@ -43,15 +43,6 @@ HTML::Perlinfo - Display a lot of Perl information in HTML format
 
 	perlinfo();
 	
-	
-	use HTML::Perlinfo;
-	use CGI qw(header);
-
-	$|++;
-
-	print header;
-	perlinfo(INFO_MODULES);
-
 =head1 DESCRIPTION
 
 This module outputs a large amount of information about your Perl installation in HTML. So far, this includes information about Perl compilation options, the Perl version, server information and environment, HTTP headers, OS version information, Perl modules, and more. 
@@ -169,28 +160,6 @@ Since the module outputs HTML, you may want to use it in a CGI script, but you d
 	print "Content-type: text/html\n\n";
 	perlinfo();
 
-I prefer to use the header function from the CGI module:
-
-	use HTML::Perlinfo;
-	use CGI qw(header);
-
-	print header;
-	perlinfo();
-
-HTML::Perlinfo stopped printing the header automatically as of version 1.43.
-
-By flushing the output buffer, you can make the HTML appear immediately. If your program is running slow, then you can try flushing the buffer.
-
-In this example, I am flushing the buffer because I know that there will be a lot of modules:
-
-	use HTML::Perlinfo;
-	use CGI qw(header);
-
-	$|++;
-
-	print header;
-	perlinfo(INFO_MODULES);
-
 Some might notice that HTML::Perlinfo shares the look and feel of the PHP function phpinfo. It was originally inspired by that function and was first released in 2004 as PHP::Perlinfo, which is no longer available on CPAN.   
 
 =head1 BUGS
@@ -212,7 +181,7 @@ Mike Accardo <accardo@cpan.org>
 
 =head1 COPYRIGHT
 
-   Copyright (c) 2004-9, Mike Accardo. All Rights Reserved.
+   Copyright (c) 2019, Mike Accardo. All Rights Reserved.
  This module is free software. It may be used, redistributed
 and/or modified under the terms of the Perl Artistic License.
 
